// JavaScript Document
function AnularCompra(varCod, varEmi, varTipo, varDoc, varUrl) {		
	if(confirm('¿ESTA SEGURO DE ANULAR ESTA COMPRA?\nFecha Emisión \t: '+varEmi+'\nTipo Doc. \t\t: '+varTipo+'\nDocumento \t\t: '+varDoc+'\nTENGA EN CUENTA QUE ESTE PROCESO ANULARA EL MOVIMIENTO QUE SE REALIZO EN EL ALMACEN')) {		
		var Ruta = varUrl+'?opt=ANUL&valor='+varCod;
		window.location.href = Ruta;	
		}
	}

// ================================ CARGAR LISTADOS ================================ //
function fn_cargar_listado_proveedor(pcod, pnom) {
	var Ruta = 'lista_proveedor.php?pcod='+pcod+'&pnom='+pnom;
	testwindow= window.open (Ruta, "mywindow", "location=no,status=no,toolbar=no,scrollbars=1,width=600,height=550");
	}
function fn_cargar_listado_marca(cod, nom) {
	var Ruta = 'lista_marca.php?cod='+cod+'&nom='+nom;
	testwindow= window.open (Ruta, "mywindow", "location=no,status=no,toolbar=no,scrollbars=1,width=600,height=550");
	}
function fn_cargar_listado_tipo(cod, nom) {
	var Ruta = 'lista_tipo.php?cod='+cod+'&nom='+nom;
	testwindow= window.open (Ruta, "mywindow", "location=no,status=no,toolbar=no,scrollbars=1,width=600,height=550");
	}
function fn_cargar_listado_material(cod, nom) {
	var Ruta = 'lista_material.php?cod='+cod+'&nom='+nom;
	testwindow= window.open (Ruta, "mywindow", "location=no,status=no,toolbar=no,scrollbars=1,width=600,height=550");
	}
function fn_cargar_listado_producto(ccod, cnom) {
	var Ruta = 'lista_producto.php?ccod='+ccod+'&cnom='+cnom;
	testwindow= window.open (Ruta, "mywindow", "location=no,status=no,toolbar=no,scrollbars=1,width=600,height=600");
	}
	
function fn_verDetalle(varCod, varUrl) {		
	var Ruta = varUrl+'?opt=VIEW&valor='+varCod;
	window.location.href = Ruta; 
	}
	
function fn_dirigir_registro(varOpt, varCod, varUrl) {
	var Ruta = varUrl+'?opt='+varOpt+'&valor='+varCod;
	window.location.href = Ruta;
	}
	
function fn_eliminar_registro(varCod, varNom, varLink) {		
		if(confirm('¿ESTA SEGURO DE ELIMINAR EL REGISTRO?\nCodigo \t: '+varCod+'\nNombre \t: '+varNom)) {
			var Ruta = varLink + '?opt=DROP&valor='+varCod;
			window.location=Ruta;
			}
		}
		
function MensajeTip(Mensaje) {
	Tip(Mensaje, BALLOON, true, ABOVE, true, OFFSETX, -17, FADEIN, 600, FADEOUT, 600, PADDING, 8);
	}

function validaCambiarClave(myForm) { 
	if (myForm.clavea && myForm.clavea.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE ESCRIBIR LA CONTRASEÑA ACTUAL");
		myForm.clavea.focus()
		return (false); 
		}
	else if (myForm.claven1 && myForm.claven1.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE ESPECIFICAR UNA NUEVA CONTRASEÑA");
		myForm.claven1.focus()
		return (false); 
		}
	else if (myForm.claven2 && myForm.claven2.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE REPETIR LA NUEVA CONTRASEÑA");
		myForm.claven2.focus()
		return (false); 
		}
	else if (myForm.claven1.value != myForm.claven2.value) { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nNO COINCIDEN LAS CONTRASEÑAS");
		myForm.claven1.focus()
		return (false); 
		}	
	else {
		return true
		}
	}
	
function validaForm(myForm) { 
	if (myForm.ccli && myForm.ccli.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UN CLIENTE");
		myForm.ccli.focus()
		return (false); 
		}
	else if (myForm.eini && myForm.eini.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UNA FECHA DE INICIO");
		myForm.eini.focus()
		return (false); 
		}
	else if (myForm.efin && myForm.efin.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UNA FECHA DE TERMINO");
		myForm.efin.focus()
		return (false); 
		}
	else if (myForm.femi && myForm.femi.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UNA FECHA");
		myForm.femi.focus()
		return (false); 
		}
	else if (myForm.mat && myForm.mat.value=="Ninguno") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UN MATERIAL");
		myForm.mat.focus()
		return (false); 
		}
	else if (myForm.pla && myForm.pla.value=="Ninguno") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UNA PLANTILLA");
		myForm.pla.focus()
		return (false); 		
		}
	else if (myForm.per && myForm.per.value=="Ninguno") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UN PERIODO");
		myForm.per.focus()
		return (false); 
		}
	else if (myForm.emp && myForm.emp.value=="Ninguno") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UNA EMPRESA");
		myForm.emp.focus()
		return (false); 
		}
	else if (myForm.age && myForm.age.value=="Ninguno") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UNA AGENCIA");
		myForm.age.focus()
		return (false); 
		}
	else if (myForm.meta && myForm.meta.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE INGRESAR UN VALOR META");
		myForm.meta.focus()
		return (false); 
		}
	else if(myForm.user && myForm.trab && myForm.user.value=="" && myForm.trab.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE INGRESAR UN PARAMETRO DE BUSQUEDA");
		myForm.user.focus()
		return (false); 
		}
	else if (myForm.valor && myForm.valor.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE INGRESAR UN VALOR REAL");
		myForm.valor.focus()
		return (false); 
		}
	else if (myForm.observa && myForm.observa.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE INGRESAR UNA OBSERVACION");
		myForm.observa.focus()
		return (false); 
		}
	else if (myForm.um && myForm.um.value=="Ninguno") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UNA UNIDAD DE MEDIDA");
		myForm.um.focus()
		return (false); 
		}
	else if (myForm.nam && myForm.nam.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE ESPECIFICAR UN NOMBRE");
		myForm.nam.focus()
		return (false); 		
		} 
	else if (myForm.nombre && myForm.nombre.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE ESPECIFICAR UN NOMBRE");
		myForm.nombre.focus()
		return (false); 		
		} 
	else if (myForm.cd && myForm.cd.value=="Ninguno") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UN CD (CENTRO DE DISTRIBUCION)");
		myForm.cd.focus()
		return (false); 		
		}	
	else if (myForm.car && myForm.car.value=="Ninguno") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UN CARGO");
		myForm.car.focus()
		return (false); 
		}
	else if (myForm.pdv && myForm.pdv.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE ESCRIBIR UN PDV");
		myForm.pdv.focus()
		return (false); 
		}
	else if (myForm.ccod && myForm.ccod.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UN CLIENTE");
		myForm.ccod.focus()
		return (false); 
		}
	else if (myForm.cnom && myForm.cnom.value=="NO EXISTE") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UN CLIENTE");
		myForm.ccod.focus()
		return (false); 
		}
	else if (myForm.clavea && myForm.clavea.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE ESCRIBIR LA CONTRASEÑA ACTUAL");
		myForm.clavea.focus()
		return (false); 
		}
	else if (myForm.claven1 && myForm.claven1.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE ESCRIBIR LA NUEVA CONTRASEÑA");
		myForm.claven1.focus()
		return (false); 
		}
	else if (myForm.claven2 && myForm.claven2.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE CONFIRMAR LA NUEVA CONTRASEÑA");
		myForm.claven2.focus()
		return (false); 
		}
	else if (myForm.claven1.value != myForm.claven2.value) { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nNO COINCIDEN LAS CONTRASEÑAS");
		myForm.claven1.focus()
		return (false); 
		}	
	else {
		return true
		}
	}

function validaRegistroProducto(myForm) { 	
	var msj_articulo="";
	var msj_stock   ="";
	var con1 = 0;
	var con2 = 0;
	var con3 = 0;
	var varPatronDoc = "^([0-9]{3})-([0-9]{7})$";
	var expreg = new RegExp (varPatronDoc);	
	var varNumItem = document.getElementById('num');

	for (i=1; i<=varNumItem.value;i++) {
		var varCodigo = document.getElementById('icod['+i+']');
		var varProduc = document.getElementById('inom['+i+']');
		var varStock  = document.getElementById('istk['+i+']');
		var varPrecio = document.getElementById('iuni['+i+']');
		var varCant   = document.getElementById('ican['+i+']');
		
		if(varCodigo.value=="" && con1==0) {
			msj_articulo = "FALTA SELECCIONAR ALGUN ARTICULO\n";
			con1++;
			}
		if(parseFloat(varPrecio.value) <= 0 || varPrecio.value=='' && con1==0) {
			msj_articulo = msj_articulo + "PRODUCTO : " + varCodigo.value + ' - ' + varProduc.value + ' -> Especificar Precio\n';
			}
		if(parseFloat(varCant.value) <= 0  || varCant.value=='' && con1==0) {
			msj_articulo = msj_articulo + "PRODUCTO : " + varCodigo.value + ' - ' + varProduc.value + ' -> Especificar una Cantidad\n';
			}
		
		if(parseFloat(varStock.value) <= 0 || varStock.value=='' && con1==0 ) {
			msj_articulo = msj_articulo + "PRODUCTO : " + varCodigo.value + ' - ' + varProduc.value + ' -> No cuenta con STOK suficiente\n';
			}
		if(parseFloat(varStock.value) < parseFloat(varCant.value) ) {
			msj_articulo = msj_articulo + "PRODUCTO : " + varCodigo.value + ' - ' + varProduc.value + ' -> No cuenta con STOK suficiente\n';
			}
		
		}

	if (myForm.tdcod && myForm.tdcod.value=="Ninguno") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UN TIPO DE DOCUMENTO");
		myForm.tdcod.focus()
		return (false); 
		}
	else if (myForm.tdnam && myForm.tdnam.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE INGRESAR UN NUMERO DE DOCUMENTO");
		myForm.tdnam.focus()
		return (false); 
		}
	else if (expreg.test(myForm.tdnam.value)==false) {
		alert("ERROR AL PROCESAR DATOS...!!!!!\nEL NUMERO DE DOCUMENTO\n DEBE TENER EL SIGUIENTE FORMATO: ###-#######\nEjemplo: 123-1234567");
		myForm.tdnam.focus()
		return (false); 
		}		
	else if (myForm.femi && myForm.femi.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE INGRESAR UNA FECHA DE EMISION");
		myForm.femi.focus()
		return (false); 
		}	
	else if (myForm.cnom && myForm.cnom.value=="NO EXISTE") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nEL CLIENTE INGRESADO NO EXISTE, DEBE SELECCIONAR UN CLIENTE VALIDO");
		myForm.ccod.focus()
		return (false); 
		}
	else if (myForm.ccod && myForm.ccod.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\n DEBE SELECCIONAR UN CLIENTE");
		myForm.ccod.focus()
		return (false); 
		}
	else if (myForm.pnom && myForm.pnom.value=="NO EXISTE") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nEL PROVEEDOR INGRESADO NO EXISTE, DEBE SELECCIONAR UN PROVEEDOR VALIDO");
		myForm.pcod.focus()
		return (false); 
		}
	else if (myForm.pcod && myForm.pcod.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\n DEBE SELECCIONAR UN PROVEEDOR");
		myForm.pcod.focus()
		return (false); 
		}
	else if (myForm.num && myForm.num.value=="0") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nNO INGRESO ITEM A ESTE DOCUMENTO\nDEBE INGRESAR AL MENOS UN IETM PARA CONTINUAR");
		myForm.btadd.focus()
		return (false); 
		}
	else if (msj_articulo!="") {
		alert("ERROR AL PROCESAR DATOS...!!!!!\n"+msj_articulo)
		return (false); 
		}
	else if (msj_stock!="") {
		alert("ERROR AL PROCESAR DATOS...!!!!!\n"+msj_stock+"\nPOR FAVOR REVISAR LAS CANTIDADES")
		return (false); 
		}
	else {
		return true
		}
	}

function validaRegistroCompra(myForm) { 	
	var msj_articulo="";
	var con1 = 0;
	var con2 = 0;
	var con3 = 0;
	var varPatronDoc = "^([0-9]{3})-([0-9]{7})$";
	var expreg = new RegExp (varPatronDoc);	
	var varNumItem = document.getElementById('num');

	for (i=1; i<=varNumItem.value;i++) {
		var varCodigo = document.getElementById('icod['+i+']');
		var varProduc = document.getElementById('inom['+i+']');
		var varPrecio = document.getElementById('iuni['+i+']');
		var varCant   = document.getElementById('ican['+i+']');
		
		if(varCodigo.value=="" && con1==0) {
			msj_articulo = "FALTA SELECCIONAR ALGUN ARTICULO\n";
			con1++;
			}
		if(parseFloat(varPrecio.value) <= 0 || varPrecio.value=='' && con1==0) {
			msj_articulo = msj_articulo + "PRODUCTO : " + varCodigo.value + ' - ' + varProduc.value + ' -> Especificar Precio\n';
			}
		if(parseFloat(varCant.value) <= 0  || varCant.value=='' && con1==0) {
			msj_articulo = msj_articulo + "PRODUCTO : " + varCodigo.value + ' - ' + varProduc.value + ' -> Especificar una Cantidad\n';
			}
		
		}

	if (myForm.tdcod && myForm.tdcod.value=="Ninguno") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE SELECCIONAR UN TIPO DE DOCUMENTO");
		myForm.tdcod.focus()
		return (false); 
		}
	else if (myForm.tdnam && myForm.tdnam.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE INGRESAR UN NUMERO DE DOCUMENTO");
		myForm.tdnam.focus()
		return (false); 
		}
	else if (expreg.test(myForm.tdnam.value)==false) {
		alert("ERROR AL PROCESAR DATOS...!!!!!\nEL NUMERO DE DOCUMENTO\n DEBE TENER EL SIGUIENTE FORMATO: ###-#######\nEjemplo: 123-1234567");
		myForm.tdnam.focus()
		return (false); 
		}		
	else if (myForm.femi && myForm.femi.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE INGRESAR UNA FECHA DE EMISION");
		myForm.femi.focus()
		return (false); 
		}	
	else if (myForm.cnom && myForm.cnom.value=="NO EXISTE") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nEL CLIENTE INGRESADO NO EXISTE, DEBE SELECCIONAR UN CLIENTE VALIDO");
		myForm.ccod.focus()
		return (false); 
		}
	else if (myForm.ccod && myForm.ccod.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\n DEBE SELECCIONAR UN CLIENTE");
		myForm.ccod.focus()
		return (false); 
		}
	else if (myForm.pnom && myForm.pnom.value=="NO EXISTE") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nEL PROVEEDOR INGRESADO NO EXISTE, DEBE SELECCIONAR UN PROVEEDOR VALIDO");
		myForm.pcod.focus()
		return (false); 
		}
	else if (myForm.pcod && myForm.pcod.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\n DEBE SELECCIONAR UN PROVEEDOR");
		myForm.pcod.focus()
		return (false); 
		}
	else if (myForm.num && myForm.num.value=="0") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nNO INGRESO ITEM A ESTE DOCUMENTO\nDEBE INGRESAR AL MENOS UN IETM PARA CONTINUAR");
		myForm.btadd.focus()
		return (false); 
		}
	else if (msj_articulo!="") {
		alert("ERROR AL PROCESAR DATOS...!!!!!\n"+msj_articulo)
		return (false); 
		}
	else if (msj_stock!="") {
		alert("ERROR AL PROCESAR DATOS...!!!!!\n"+msj_stock+"\nPOR FAVOR REVISAR LAS CANTIDADES")
		return (false); 
		}
	else {
		return true
		}
	}
	
function validaRegistroPago(myForm) {		
	if (myForm.femi && myForm.femi.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE INGRESAR UNA FECHA DE PAGO");
		myForm.femi.focus()
		return (false); 
		}	
	else if (myForm.txtpago && myForm.txtpago.value=="") { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nDEBE INGRESAR UN MONTO A PAGAR");
		myForm.txtpago.focus()
		return (false); 
		}
	else if (parseFloat(myForm.txtpago.value) > parseFloat(myForm.txtsal.value)) { 
		alert("ERROR AL PROCESAR DATOS...!!!!!\nEL MONTO A PAGAR NO DEBE SER MAYOR AL SALDO DEL DOCUMENTO");
		myForm.txtpago.focus()
		return (false); 
		}
	else {
		return true
		}
	}
	
function SoloEnteros(e) { // 1
    tecla = (document.all) ? e.keyCode : e.which; // 2
    if (tecla==8 || tecla==0) return true; // 3
    //patron =/[A-Za-z\s]/; // Solo Letras
	patron =/[0-9\d]/; // Solo Numeros
    te = String.fromCharCode(tecla); // 5
    return patron.test(te); // 6	
	}

function SoloNumeros(e) { // 1
    tecla = (document.all) ? e.keyCode : e.which; // 2
    if (tecla==8 || tecla==0) return true; // 3
    //patron =/[A-Za-z\s]/; // Solo Letras
	patron =/^[0-9]*\.?[0-9]*$/; // Solo Numeros
    te = String.fromCharCode(tecla); // 5
    return patron.test(te); // 6	
	}


function validaNumero(Valor) {	
	if(Valor=='') return false;
	var reg =  /^[0-9]*\.?[0-9]*$/;
	if(reg.test(Valor)) return true;
	else return false;
//	if(isNaN(Campo) || Campo.split('.')[1].length>5) return false;
//	return true;
	} 
function PintarFila(scr) {
	scr.className = "select";
	}

function PintarFilaOrig(scr, clase) {
	scr.className = clase;
	}
function uno(src,color_entrada) { 
	
    src.bgColor=color_entrada;src.style.cursor="default"; 
}
function dos(src,color_default) { 
    src.bgColor=color_default;src.style.cursor="default"; 
}
function redondear(cantidad, decimales) {
	var cantidad = parseFloat(cantidad);
	var decimales = parseFloat(decimales);
	decimales = (!decimales ? 2 : decimales);
	return Math.round(cantidad * Math.pow(10, decimales)) / Math.pow(10, decimales);
	} 