<?php
if(isset($_POST["bexp"])) {		
	$sql = "call spQuery_Producto('$_POST[cod]', '$_POST[nam]', '$_POST[pcod]', '$_POST[mcod]', '$_POST[tcod]','$_POST[xcod]')";
	$_SESSION["expor_sql_1"] =  $sql;
	$_SESSION["expor_sql_2"] = NULL;
	$varTitulo = (isset($_POST["titu"]))?$_POST["titu"]:"Reporte";
	$dir = "export.php?page=$varTitulo";
	header("location: $dir");
	}
require_once('clases/xajax/xajax_core/xajax.inc.php');
$xajax = new xajax();
//$xajax->setFlag('debug',true); 
$xajax->configure('javascript URI', 'clases/xajax/');

function seleccionar_proveedor($ide) {
	if($ide<>"") {
		$var = VarServer("MYSQLI");
		$obj = new clsConexion($var[0],$var[1],$var[2],$var[3],$var[4]);
		$obj->AbrirConexion();
		$sql = "call spQuery_Lista_Proveedor('$ide','');";
		$rs = $obj->Query($sql);
		$obj->CerrarConexion();
		$Fila = $obj->FetchArray($rs);
		if($obj->NumFilas($rs)>0) $retorna = $Fila[1];
		else $retorna = "NO EXISTE";		
		}
	else $retorna = "";
	
	$objResponse = new xajaxResponse();
	$objResponse->assign("pnom", "value", $retorna);
	return $objResponse;	
		
	}

function seleccionar_marca($ide) {
	if($ide<>"") {
		$var = VarServer("MYSQLI");
		$obj = new clsConexion($var[0],$var[1],$var[2],$var[3],$var[4]);
		$obj->AbrirConexion();
		$sql = "call spQuery_Lista_Marca('$ide','');";
		$rs = $obj->Query($sql);
		$obj->CerrarConexion();
		$Fila = $obj->FetchArray($rs);
		if($obj->NumFilas($rs)>0) $retorna = $Fila[1];
		else $retorna = "NO EXISTE";		
		}
	else $retorna = "";
	
	$objResponse = new xajaxResponse();
	$objResponse->assign("mnom", "value", $retorna);
	return $objResponse;		
	}

function seleccionar_tipo($ide) {
	if($ide<>"") {
		$var = VarServer("MYSQLI");
		$obj = new clsConexion($var[0],$var[1],$var[2],$var[3],$var[4]);
		$obj->AbrirConexion();
		$sql = "call spQuery_Lista_Tipo('$ide','');";
		$rs = $obj->Query($sql);
		$obj->CerrarConexion();
		$Fila = $obj->FetchArray($rs);
		if($obj->NumFilas($rs)>0) $retorna = $Fila[1];
		else $retorna = "NO EXISTE";		
		}
	else $retorna = "";
	
	$objResponse = new xajaxResponse();
	$objResponse->assign("tnom", "value", $retorna);
	return $objResponse;		
	}
	
function seleccionar_material($ide) {
	if($ide<>"") {
		$var = VarServer("MYSQLI");
		$obj = new clsConexion($var[0],$var[1],$var[2],$var[3],$var[4]);
		$obj->AbrirConexion();
		$sql = "call spQuery_Lista_Material('$ide','');";
		$rs = $obj->Query($sql);
		$obj->CerrarConexion();
		$Fila = $obj->FetchArray($rs);
		if($obj->NumFilas($rs)>0) $retorna = $Fila[1];
		else $retorna = "NO EXISTE";		
		}
	else $retorna = "";
	
	$objResponse = new xajaxResponse();
	$objResponse->assign("xnom", "value", $retorna);
	return $objResponse;		
	}
$xajax->register(XAJAX_FUNCTION, 'seleccionar_proveedor');
$xajax->register(XAJAX_FUNCTION, 'seleccionar_marca');
$xajax->register(XAJAX_FUNCTION, 'seleccionar_tipo');
$xajax->register(XAJAX_FUNCTION, 'seleccionar_material');
$xajax->processRequest();
$xajax->printJavascript("clases/xajax");

?>
<script language="javascript">	
	function DeleteRow(x) {
		while (x.tagName.toLowerCase() !='tr') {
			if(x.parentElement)
				x=x.parentElement;
			else if(x.parentNode)
				x=x.parentNode;
			else
			return;
			}
		var rowNum=x.rowIndex;
		while (x.tagName.toLowerCase() !='table') {
			if(x.parentElement)
				x=x.parentElement;
			else if(x.parentNode)
				x=x.parentNode;
			else
				return;
			}
		x.deleteRow(rowNum);
		}
</script>
<?php

function MyTable($obj, $Titulo, $Opcion, $Valor) {
	$Link = $_SERVER['PHP_SELF'];
	$MyTabla = "_sv_producto";
	$myID = "id_producto";
	$varCod = (isset($_POST["cod"]))?$_POST["cod"]:NULL;
	$varNom = (isset($_POST["nam"]))?$_POST["nam"]:NULL;
	
	if(!isset($Opcion)) {
		$varTabla=array("id"=>"tabla", "name"=>"table", "tamano"=>"500", "clase"=>"FormTitulo", "titulo"=>$Titulo." - BUSQUEDA",
					"formu"=>array("id"=>"form", "name"=>"form", "metodo"=>"POST"),						
					"ocult"=>array(array("tipo"=>"oculto", "id"=>"titu", "name"=>"titu", "valor"=>$Titulo),
								   array("tipo"=>"oculto", "id"=>"opt", "name"=>"opt", "valor"=>$Opcion)
								  ),
					"conte"=>array(array("titulo"=>"Codigo :", "clase1"=>"FormCampo1", "clase2"=>"interior", "tamano"=>"100",
										 "campo" =>array("tipo"=>"texto", "id"=>"cod", "name"=>"cod", 
										 "alinear"=>"center","valor"=>$_POST["cod"], "ancho"=>"70")),
								   array("titulo"=>"Descripción :", "clase1"=>"FormCampo1", "clase2"=>"interior", 
										  "campo" =>array("tipo"=>"texto", "id"=>"nam", "name"=>"nam",
										  "valor"=>$_POST["nam"],  "ancho"=>"355")),
								   array("titulo"=>"Proveedor :", "clase1"=>"FormCampo1", "clase2"=>"interior",
										     "campo"=>array("tipo"=>"varios",
														    "contenido"=>array(array("tipo"=>"text", "id"=>"pcod", "name"=>"pcod", "valor"=>$_POST["pcod"], "ancho"=>"50", 
																				   	 "alinear"=>"center", "blur"=>"xajax_seleccionar_proveedor(this.value)", 
																					 "dclick"=>"fn_cargar_listado_proveedor('pcod', 'pnom')"),
																			   array("tipo"=>"text", "id"=>"pnom", "name"=>"pnom", "valor"=>$_POST["pnom"], "ancho"=>"300",
																			   		 "clase"=>"inputDisable", "locked"=>"SI")
																			   )
														 )
										  	 ),	
								   array("titulo"=>"Marca :", "clase1"=>"FormCampo1", "clase2"=>"interior",
										     "campo"=>array("tipo"=>"varios",
														    "contenido"=>array(array("tipo"=>"text", "id"=>"mcod", "name"=>"mcod", "valor"=>$_POST["mcod"], "ancho"=>"50", 
																				   	 "alinear"=>"center", "blur"=>"xajax_seleccionar_marca(this.value)", 
																					 "dclick"=>"fn_cargar_listado_marca('mcod', 'mnom')"),
																			   array("tipo"=>"text", "id"=>"mnom", "name"=>"mnom", "valor"=>$_POST["mnom"], "ancho"=>"300",
																			   		 "clase"=>"inputDisable", "locked"=>"SI")
																			   )
														 )
										  	 ),	
								  array("titulo"=>"Tipo :", "clase1"=>"FormCampo1", "clase2"=>"interior",
										     "campo"=>array("tipo"=>"varios",
														    "contenido"=>array(array("tipo"=>"text", "id"=>"tcod", "name"=>"tcod", "valor"=>$_POST["tcod"], "ancho"=>"50", 
																				   	 "alinear"=>"center", "blur"=>"xajax_seleccionar_tipo(this.value)", 
																					 "dclick"=>"fn_cargar_listado_tipo('tcod', 'tnom')"),
																			   array("tipo"=>"text", "id"=>"tnom", "name"=>"tnom", "valor"=>$_POST["tnom"], "ancho"=>"300",
																			   		 "clase"=>"inputDisable", "locked"=>"SI")
																			   )
														 )
										  	 ),	
								 array("titulo"=>"Material :", "clase1"=>"FormCampo1", "clase2"=>"interior",
										     "campo"=>array("tipo"=>"varios",
														    "contenido"=>array(array("tipo"=>"text", "id"=>"xcod", "name"=>"xcod", "valor"=>$_POST["xcod"], "ancho"=>"50", 
																				   	 "alinear"=>"center", "blur"=>"xajax_seleccionar_material(this.value)", 
																					 "dclick"=>"fn_cargar_listado_material('xcod', 'xnom')"),
																			   array("tipo"=>"text", "id"=>"xnom", "name"=>"xnom", "valor"=>$_POST["xnom"], "ancho"=>"300",
																			   		 "clase"=>"inputDisable", "locked"=>"SI")
																			   )
														 )
										  	 )
								   ),
					"boton"=>array(array("tipo"=>"submit", "id"=>"bcon", "name"=>"bcon", "ancho"=>"80", "alto"=>"22", "texto"=>"Buscar"),
								   array("tipo"=>"submit", "id"=>"bexp", "name"=>"bexp", "ancho"=>"80", "alto"=>"22", "texto"=>"Exportar"),								  
								   array("tipo"=>"button", "id"=>"bnew", "name"=>"bnew", "ancho"=>"80", "alto"=>"22", "texto"=>"(+) Nuevo", "click"=>"location='$Link?opt=NEW'"),
								   )
					);
		echo $obj->setTablaForm($varTabla);
		$sql = "call spQuery_Producto('$varCod', '$varNom', '$_POST[pcod]', '$_POST[mcod]', '$_POST[tcod]','$_POST[xcod]')";
	
		$varTabla=array("id"=>"theTable", "name"=>"theTable", "tamano"=>"98%", "sql_cab"=>$sql,	"pages"=>20,
						"conte"=>array(array("titulo"=>"CART",     "ancho"=>"40" , "alinear"=>"center", "clase"=>"sortable-numeric", "tipo"=>"texto"), 
									   array("titulo"=>"ARTICULO", "ancho"=>"300", "clase"  =>"sortable"),
									   array("titulo"=>"CPRO",     "ancho"=>"40" , "oculto"=>"SI"), 
									   array("titulo"=>"PROVEEDOR","ancho"=>"300", "clase"  =>"sortable"),
									   array("titulo"=>"UM_COM","ancho"=>"60", "clase"  =>"sortable", "alinear"=>"center"),
									   array("titulo"=>"UM_COM","ancho"=>"60" , "oculto"=>"SI"),
									   array("titulo"=>"UM_VEN", "ancho"=>"60", "clase"  =>"sortable", "alinear"=>"center"),
									   array("titulo"=>"UM_VEN", "ancho"=>"60" , "oculto"=>"SI"),
									   array("titulo"=>"UM_STK", "ancho"=>"60", "clase"  =>"sortable", "alinear"=>"center"),
									   array("titulo"=>"UM_STK", "ancho"=>"60" , "oculto"=>"SI"),
									   array("titulo"=>"CMAR",     "ancho"=>"40" , "oculto"=>"SI"), 
									   array("titulo"=>"MARCA",    "ancho"=>"120"),
									   array("titulo"=>"CTIP",     "ancho"=>"40" , "oculto"=>"SI"), 
									   array("titulo"=>"TIPO", 	   "ancho"=>"120"),
									   array("titulo"=>"CMAT",     "ancho"=>"40" , "oculto"=>"SI"), 
									   array("titulo"=>"MATERIAL", "ancho"=>"120"),
									   array("titulo"=>"P.VENTA",  "ancho"=>"60",  "alinear"=>"right", "clase"=>"sortable-numeric", "oculto"=>"SI"),
									   array("titulo"=>"P.COMPRA", "ancho"=>"60",  "alinear"=>"right", "clase"=>"sortable-numeric", "oculto"=>"SI"),
									   array("titulo"=>"FCREADO",  "ancho"=>"100", "oculto"=>"SI"),
									   array("titulo"=>"FUPDATE",  "ancho"=>"100", "oculto"=>"SI"),
									   array("titulo"=>"UCREADO",  "ancho"=>"100", "oculto"=>"SI"),
									   array("titulo"=>"UUPDATE",  "ancho"=>"100", "oculto"=>"SI")
									   ),
						"boton"=>array(array("tipo"=>"img", "id"=>"bbus", "name"=>"bbus", "img"=>"images/b_table_edit.png", 
											 "toltip"=>array(array("valor"=>"HAGA CLICK PARA <b>EDITAR</b> EL REGISTRO<br><b>"),
																 array("valor"=>0, "tipo"=>"INDEX"),
																 array("valor"=>" - "),
																 array("valor"=>1, "tipo"=>"INDEX"),
																 array("valor"=>"</b>")
												   				),
											 "click"=>array("funcion"=>"fn_dirigir_registro",
															"param"=>array(array("valor"=>"EDIT","tipo"=>"TEXTO"),
																		   array("valor"=>0, 	 "tipo"=>"INDEX"),
																		   array("valor"=>$Link, "tipo"=>"TEXTO")
																		  )
															)
											 
											),
									   array("tipo"=>"img", "id"=>"badd", "name"=>"badd", "img"=>"images/b_table_delete.png", 
											 "toltip"=>array(array("valor"=>"HAGA CLICK PARA <b>ELIMINAR</b> EL REGISTRO<br><b>"),
																 array("valor"=>0, "tipo"=>"INDEX"),
																 array("valor"=>" - "),
																 array("valor"=>1, "tipo"=>"INDEX"),
																 array("valor"=>"</b>")
												   				),
											 "click"=>array("funcion"=>"fn_eliminar_registro",
															"param"=>array(array("valor"=>0, "tipo"=>"INDEX"),
																		   array("valor"=>1, "tipo"=>"INDEX"),
																		   array("valor"=>$Link, "tipo"=>"TEXTO")
																		   )
															)
											 )
									)
						);
		echo $obj->SetGridTabla($varTabla);
		}
	elseif($Opcion=="NEW" || $Opcion=="EDIT") {
		if($Opcion=="NEW") {
			$SubTit = $Titulo." - NUEVO";
			$Permite = $_SESSION["_FINS"];
			$Fila = NULL;
			}
		else {
			$SubTit =  $Titulo." - EDITAR";
			$Permite = $_SESSION["_FUPD"];
			$sql = "select * from $MyTabla where $myID = $Valor";		
			$obj->AbrirConexion();
			$rs = $obj->Query($sql);
			$obj->CerrarConexion();
			$Fila = $obj->FetchArray($rs);
			}
		if($Permite<>"S") {
			echo "<script language='Javascript'>";
			echo "window.location='$Link'";
			echo "</script>\n";
			}
		$sqlmar = "call spQuery_Combo_Producto_Marca()";
		$sqltip = "call spQuery_Combo_Producto_Tipo()";
		$sqlmat = "call spQuery_Combo_Producto_Material()";
		$sqlpro = "call spQuery_Combo_Proveedor();";
		$varTabla=array("id"=>"tabla", "name"=>"table", "tamano"=>"400", "clase"=>"FormTitulo", "titulo"=>$SubTit,
					"formu"=>array("id"=>"form", "name"=>"form", "metodo"=>"POST"),						
					"ocult"=>array(array("tipo"=>"oculto", "id"=>"titu", "name"=>"titu", "valor"=>$Titulo),
								   array("tipo"=>"oculto", "id"=>"opt", "name"=>"opt", "valor"=>$Opcion)
								  ),
					"conte"=>array(array("titulo"=>"Codigo :", "clase1"=>"FormCampo1", "clase2"=>"interior", "tamano"=>"100",
										 "campo" =>array("tipo"=>"texto", "id"=>"cod", "name"=>"cod", "clase"=>"inputDisable",
										 "valor"=>$Fila[$myID], "alinear"=>"center", "locked"=>"SI", "ancho"=>"70")),
								   array("titulo"=>"Marca :", "clase1"=>"FormCampo1", "clase2"=>"interior",
										 "campo"=>array("tipo"=>"select", "id"=>"mar", "name"=>"mar", "valor"=>$Fila["id_marca"],
														"combo"=>array("sql"=>$sqlmar, "ancho"=>"250", "sincod"=>"SI"))),
								   array("titulo"=>"Tipo :", "clase1"=>"FormCampo1", "clase2"=>"interior",
										 "campo"=>array("tipo"=>"select", "id"=>"tip", "name"=>"tip", "valor"=>$Fila["id_tipo"],
														"combo"=>array("sql"=>$sqltip, "ancho"=>"250", "sincod"=>"SI"))),
								   array("titulo"=>"Material :", "clase1"=>"FormCampo1", "clase2"=>"interior",
										 "campo"=>array("tipo"=>"select", "id"=>"mat", "name"=>"mat", "valor"=>$Fila["id_material"],
														"combo"=>array("sql"=>$sqlmat, "ancho"=>"250", "sincod"=>"SI"))),
								   array("titulo"=>"Descripción :", "clase1"=>"FormCampo1", "clase2"=>"interior", 
										 "campo" =>array("tipo"=>"texto", "id"=>"nam", "name"=>"nam", "valor"=>$Fila["descripcion"], "ancho"=>"250")),
								   array("titulo"=>"Precio Venta :", "clase1"=>"FormCampo1", "clase2"=>"interior", 
										 "campo" =>array("tipo"=>"texto", "id"=>"prev", "name"=>"prev", "valor"=>$Fila["precio_venta"], 
										 "ancho"=>"100", "keypress"=>"return SoloNumeros(event)"),
										 ),
								   array("titulo"=>"Precio Compra :", "clase1"=>"FormCampo1", "clase2"=>"interior", 
										 "campo" =>array("tipo"=>"texto", "id"=>"prec", "name"=>"prec", "valor"=>$Fila["precio_compra"], 
										 "ancho"=>"100", "keypress"=>"return SoloNumeros(event)"),
										 )
								   ),
					"boton"=>array(array("tipo"=>"submit", "id"=>"bsav", "name"=>"bsav", "ancho"=>"80", "alto"=>"22", 
										 "texto"=>"Grabar", "click"=>"return confirm('¿ DESEAR GUARDAR LOS DATOS ?')"),			  
								   array("tipo"=>"button", "id"=>"breg", "name"=>"breg", "ancho"=>"80", "alto"=>"22", 
										 "texto"=>"Regresar", "click"=>"location='$Link'"),
								)
					);
		echo $obj->setTablaForm($varTabla);	
		}
	elseif($Opcion=="DROP") {
		if($_SESSION["_FDEL"]<>"S") {
			echo "<script language='Javascript'>";
			echo "window.location='$Link'";
			echo "</script>\n";
			}
		$sql = "update $MyTabla set _estado='X' where $myID = $Valor";
		$obj->AbrirConexion();
		$obj->Query($sql);
		$obj->CerrarConexion();	
		echo "<script language='Javascript'>";
		echo "window.location='$Link'";
		echo "</script>\n";
		}
	if(isset($_POST["bsav"])) {	
		$varUse = (isset($_SESSION["_CUSE"]))? 1 : $_SESSION["_CUSE"];
		$varCod = ($_POST["cod"]=="") ? "NULL" : $_POST["cod"];
		$varPreV = ($_POST["prev"]=="") ? "NULL" : $_POST["prev"];
		$varPreC = ($_POST["prec"]=="") ? "NULL" : $_POST["prec"];
		$varMar = ($_POST["mar"]=="") ? "NULL" : $_POST["mar"];
		$varTip = ($_POST["tip"]=="") ? "NULL" : $_POST["tip"];
		$varMat = ($_POST["mat"]=="") ? "NULL" : $_POST["mat"];
		
		$sql = "call spMante_Producto('$_POST[opt]', $varCod, $varMar, $varTip, $varMat, '$_POST[nam]', $varPreV, $varPreC, $varUse);";
		$obj->AbrirConexion();
		$obj->Query($sql);
		$obj->CerrarConexion();	
		echo "<script language='Javascript'>";
